> #### 🔊亲爱的pity用户: {notification_user}
> 🎉测试计划 <font color=#1890ff>{plan_name}</font> 执行完毕
> 
> 🎁测试环境 **{env}** 执行人 **{executor}**
>
> 🤖测试结果 <font color={result_color} face="黑体">{plan_result}</font>
> 
> 🏆成功 <font color=#67C23A>{success}</font>
> 
> 📜**失败** <font color=#F56C6C>{failed}</font>
> 
> 🔨**出错** <font color=#E6A23C>{error}</font>
> 
> ⌛开始时间: <font color=#909399>{start_time}</font>
> 
> 🎨完成时间: <font color=#909399>{end_time}</font>
> 
> [👉点击此处查看具体报告]({report_url})
